/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Annozilla.
 *
 * The Initial Developer of the Original Code is
 * Doug Daniels <rainking@alumni.rice.edu>
 * Portions created by the Initial Developer are Copyright (C) 2003
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *  Matthew Wilson <matthew@mjwilson.demon.co.uk>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

/**
 * Code to handle context menu's "Annotate selection" option.
 */

function annozillaAnnotateSelection(isFirefox) {
    if (! Components.classes["@mozilla.org/xpointer-service;1"]) {
	window.alert("Please install the XPointerService from http://xpointerlib.mozdev.org/");
        return;
    }
    
    var focusedWindow = document.commandDispatcher.focusedWindow;
    var wrapper = new XPCNativeWrapper(focusedWindow, 'getSelection()');
    var seln = wrapper.getSelection ();
    var url = annozillaStripURL(focusedWindow.location.href);
    
    var xptrService = Components.classes["@mozilla.org/xpointer-service;1"].
           getService().QueryInterface(Components.interfaces.nsIXPointerService);
    
    var xptr = xptrService.createXPointerFromSelection(seln, focusedWindow.document);

    // TODO Logic to choose between editors is duplicated in annozilla.js
    if (isFirefox) {
        window.openDialog("chrome://annozilla/content/editor/editor.xul",
                "annotation-body" + Math.random(),
                "chrome,resizable,dialog=no",
                null,
                url,
                xptr,
                null);
    } else {
        window.openDialog("chrome://annozilla/content/editor/composer.xul",
                "annotation-body" + Math.random(),
                "chrome,resizable,dialog=no",
                null,
                url,
                xptr,
                null);
    }
}

/**
 * Private function to strip query strings off of URLs. (we don't want to be
 * nosy!)
 * Also strips off fragment ids
 * TODO Duplicated in annozilla.js.
 *
 * @param url String URL to strip query strings from
 * @return URL string stripped of queries and fragment ids
 */
function annozillaStripURL(url) {
  if (!url || ('string' != typeof(url)) ||  ('' == url) || url == 'about:blank') {
    return "about:blank";
  }
  
  // Strip off any query strings (Don't want to be too nosy).
  var queryPart = url.indexOf('?');
  if (queryPart != -1) {
    url = url.slice(0, queryPart);
  }

  url = url.replace (/#.*/,'');

  return url;    
}
